@@ -3,7 +3,7 @@ from duality import eoq as eoq
 from duality import hub
 from duality.misc.global_functions import *
 from duality import montecarlo
-from misc._meta import (
+from unin.misc._meta import (
 	__author__,
 	__copyright__,
 	__credits__,
